"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _react = _interopRequireDefault(require("react"));
var _charts = require("echarts/charts");
var _components = require("echarts/components");
var echarts = _interopRequireWildcard(require("echarts/core"));
var _renderers = require("echarts/renderers");
var _core2 = _interopRequireDefault(require("echarts-for-react/lib/core"));
var _ramda = require("ramda");
var _auxiliarFunctions = require("../../lib/auxiliarFunctions");
var _commonStyles = require("../../commonStyles");
var _theme = require("flipper-ui/theme");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, "default": e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); return f; })(e, t); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2["default"])(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var _theme$colors = _theme.theme.colors,
  blue = _theme$colors.blue,
  green = _theme$colors.green,
  neutral = _theme$colors.neutral,
  orange = _theme$colors.orange,
  red = _theme$colors.red;
echarts.use([_components.GridComponent, _components.TitleComponent, _renderers.CanvasRenderer, _components.LegendComponent, _components.TooltipComponent, _components.ToolboxComponent, _charts.LineChart, _components.MarkLineComponent, _components.DataZoomInsideComponent, _components.DataZoomSliderComponent]);
var ForecastAreaChart = function ForecastAreaChart(props) {
  var _toolboxTooltip$saveA, _toolboxTooltip$dataV;
  var data = props.data,
    grid = props.grid,
    width = props.width,
    color = props.color,
    title = props.title,
    xType = props.xType,
    yType = props.yType,
    tooltip = props.tooltip,
    yComplement = props.yComplement,
    rotateLabel = props.rotateLabel,
    forecastColor = props.forecastColor,
    lineMarkColor = props.lineMarkColor,
    lineMarkValue = props.lineMarkValue,
    fontLabelSize = props.fontLabelSize,
    toolboxTooltip = props.toolboxTooltip,
    tooltipComplement = props.tooltipComplement,
    forecastChartLegends = props.forecastChartLegends;
  var yData = data.map(function (item) {
    return item.result;
  });
  var xData = data.map(function (item) {
    return (0, _auxiliarFunctions.toDate)(item.label, 'yyyy-MM-dd HH:mm').toString();
  });
  var formatLabel = function formatLabel(chartValues) {
    var data = chartValues.data;
    return yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(Number(data)).toString() : (0, _auxiliarFunctions.takeLabelComplement)(Number(Number(data).toFixed(2)), yComplement !== null && yComplement !== void 0 ? yComplement : '').toString();
  };
  var dinamicData = function dinamicData(item, charts) {
    var dataRange = item.end - item.start;
    var dataLimit = 700 / xData.length;
    if (dataRange < dataLimit) {
      return charts.setOption({
        series: [{
          label: {
            show: true,
            distance: 1.1,
            position: 'top',
            color: neutral[200],
            formatter: formatLabel,
            fontSize: yType === 'time' ? 10 : 11.5
          }
        }]
      });
    }
    charts.setOption({
      series: [{
        label: {
          show: false
        }
      }]
    });
  };
  var formatTooltip = function formatTooltip(chartValues) {
    var current = tooltip.current,
      forecast = tooltip.forecast;
    var _ref = chartValues.length === 2 ? chartValues[1] : chartValues[0],
      axisValueLabel = _ref.axisValueLabel,
      data = _ref.data;
    var _ref2 = chartValues.length === 2 ? current : forecast,
      label = _ref2.label,
      result = _ref2.result;
    var complement = tooltipComplement ? tooltipComplement : '';
    var values = yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(Number(data)) : (0, _auxiliarFunctions.takeLabelComplement)(Number(Number(data).toFixed(2)), yComplement !== null && yComplement !== void 0 ? yComplement : '');
    return "".concat(label, ": ").concat((0, _auxiliarFunctions.formatTooltipWithHours)(axisValueLabel), " <br>\n      ").concat(result, ": ").concat(values, " <br>\n      ").concat(complement);
  };
  var zoomEvent = {
    dataZoom: dinamicData
  };
  var series = [{
    type: 'line',
    data: yData,
    name: forecastChartLegends ? forecastChartLegends.forecast : '',
    label: _objectSpread(_objectSpread({
      show: true,
      distance: 1.1,
      position: 'top'
    }, _commonStyles.COMMON_STYLE), {}, {
      fontSize: yType === 'time' ? 10 : 11.5,
      formatter: typeof yComplement === 'function' ? yComplement.toString() : formatLabel
    }),
    lineStyle: {
      color: forecastColor || orange[600]
    },
    itemStyle: {
      color: forecastColor || orange[600]
    },
    areaStyle: {
      color: forecastColor || orange[600],
      opacity: 0
    },
    markLine: {
      symbol: '',
      silent: true,
      animation: false,
      data: [{
        name: (forecastChartLegends === null || forecastChartLegends === void 0 ? void 0 : forecastChartLegends.lineMark) || 'markLine',
        xAxis: lineMarkValue && xData[lineMarkValue - 1].toString()
      }],
      label: {
        show: true,
        formatter: forecastChartLegends === null || forecastChartLegends === void 0 ? void 0 : forecastChartLegends.lineMark,
        color: lineMarkColor || neutral[200]
      },
      lineStyle: {
        width: 1,
        type: 'solid',
        color: lineMarkColor || red[500]
      },
      emphasis: {
        lineStyle: {
          width: 50,
          type: 'solid',
          color: lineMarkColor || green[800]
        }
      }
    }
  }, {
    type: 'line',
    name: (forecastChartLegends === null || forecastChartLegends === void 0 ? void 0 : forecastChartLegends.current) || '',
    data: lineMarkValue && (0, _ramda.take)(lineMarkValue, yData),
    label: _objectSpread(_objectSpread({
      show: false,
      distance: 1.1,
      position: 'top'
    }, _commonStyles.COMMON_STYLE), {}, {
      fontSize: yType === 'time' ? 10 : 11.5,
      formatter: typeof yComplement === 'function' ? yComplement.toString() : formatLabel
    }),
    lineStyle: {
      color: color || blue[600]
    },
    itemStyle: {
      color: color || blue[600]
    },
    areaStyle: {
      color: color || blue[600],
      opacity: 0.2
    }
  }];
  var scrollable = xData.length > 5 ? [{
    type: 'inside',
    zoomLock: true,
    endValue: lineMarkValue,
    zoomOnMouseWheel: 'shift',
    startValue: lineMarkValue && lineMarkValue - 2
  }, {
    type: 'slider',
    bottom: 10,
    show: true,
    startValue: lineMarkValue && lineMarkValue - 1,
    endValue: lineMarkValue && lineMarkValue + 3,
    labelFormatter: function labelFormatter(_, item) {
      return (0, _auxiliarFunctions.formatTime)(item, 'dd/MM/yyyy');
    }
  }] : [];
  var toolbox = toolboxTooltip && _objectSpread(_objectSpread({}, _commonStyles.TOOLBOX_DEFAULT_PROPS), {}, {
    feature: {
      saveAsImage: toolboxTooltip.saveAsImage && (0, _auxiliarFunctions.getSaveAsImage)((_toolboxTooltip$saveA = toolboxTooltip.saveAsImage.title) !== null && _toolboxTooltip$saveA !== void 0 ? _toolboxTooltip$saveA : ''),
      dataView: toolboxTooltip.dataView && (0, _auxiliarFunctions.getDataView)((_toolboxTooltip$dataV = toolboxTooltip.dataView.title) !== null && _toolboxTooltip$dataV !== void 0 ? _toolboxTooltip$dataV : '')
    }
  });
  var options = function options() {
    return {
      series: series,
      dataZoom: scrollable,
      grid: _objectSpread(_objectSpread({}, grid || {
        bottom: 75
      }), {}, {
        show: true
      }),
      title: {
        text: title,
        left: '6.2%',
        textStyle: _objectSpread({}, _commonStyles.TITLE_STYLE)
      },
      xAxis: {
        type: 'category',
        data: xData,
        boundaryGap: false,
        splitLine: {
          show: true,
          lineStyle: _objectSpread({}, _commonStyles.AXIS_SPLIT_LINE)
        },
        axisLabel: _objectSpread(_objectSpread({}, _commonStyles.COMMON_STYLE), {}, {
          rotate: rotateLabel || 0,
          fontSize: fontLabelSize || 11.5,
          formatter: function formatter(item) {
            return xType === 'time' ? (0, _auxiliarFunctions.formatTime)(item, 'dd MMM') : item;
          }
        })
      },
      yAxis: {
        type: 'value',
        max: _auxiliarFunctions.getDomain,
        splitLine: {
          show: true,
          lineStyle: _objectSpread({}, _commonStyles.AXIS_SPLIT_LINE)
        },
        axisTick: {
          show: true
        },
        axisLine: {
          show: true,
          onZero: true,
          lineStyle: {
            color: neutral[200]
          }
        },
        axisLabel: _objectSpread(_objectSpread({}, _commonStyles.COMMON_STYLE), {}, {
          fontSize: fontLabelSize || 11.5,
          margin: yType === 'time' ? 16 : 14,
          formatter: function formatter(item) {
            return yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(Number(item)).toString() : (0, _auxiliarFunctions.takeLabelComplement)(Number(item.toFixed(2)), yComplement !== null && yComplement !== void 0 ? yComplement : '').toString();
          }
        })
      },
      legend: {
        top: 20,
        itemGap: 30,
        selectedMode: false,
        textStyle: _objectSpread({}, _commonStyles.COMMON_STYLE),
        data: [forecastChartLegends === null || forecastChartLegends === void 0 ? void 0 : forecastChartLegends.current, forecastChartLegends === null || forecastChartLegends === void 0 ? void 0 : forecastChartLegends.forecast]
      },
      tooltip: _objectSpread({
        trigger: 'axis',
        formatter: formatTooltip
      }, _commonStyles.TOOLTIP_DEFAULT_PROPS),
      toolbox: _objectSpread(_objectSpread({}, toolbox), {}, {
        tooltip: _objectSpread(_objectSpread({}, _commonStyles.TOOLTIP_DEFAULT_PROPS), {}, {
          formatter: function formatter(param) {
            return "<div>".concat(param.title, "</div>");
          }
        })
      })
    };
  };
  return /*#__PURE__*/_react["default"].createElement(_core2["default"], {
    notMerge: true,
    lazyUpdate: true,
    echarts: echarts,
    option: options(),
    style: {
      width: '99.9%',
      height: 300
    },
    opts: {
      renderer: 'canvas',
      width: width !== null && width !== void 0 ? width : 'auto'
    },
    onEvents: zoomEvent
  });
};
var _default = exports["default"] = ForecastAreaChart;