"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof3 = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _react = _interopRequireDefault(require("react"));
var _charts = require("echarts/charts");
var _components = require("echarts/components");
var echarts = _interopRequireWildcard(require("echarts/core"));
var _renderers = require("echarts/renderers");
var _core2 = _interopRequireDefault(require("echarts-for-react/lib/core"));
var _auxiliarFunctions = require("../../lib/auxiliarFunctions");
var _commonStyles = require("../../commonStyles");
var _theme = require("flipper-ui/theme");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, "default": e }; if (null === e || "object" != _typeof3(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); return f; })(e, t); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2["default"])(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var neutral = _theme.theme.colors.neutral;
echarts.use([_components.GridComponent, _components.TitleComponent, _renderers.CanvasRenderer, _components.LegendComponent, _components.TooltipComponent, _components.ToolboxComponent, _charts.LineChart, _components.DataZoomInsideComponent, _components.DataZoomSliderComponent]);
var LineChart = function LineChart(props) {
  var _toolboxTooltip$saveA, _toolboxTooltip$dataV;
  var data = props.data,
    grid = props.grid,
    title = props.title,
    width = props.width,
    xType = props.xType,
    yType = props.yType,
    colors = props.colors,
    smooth = props.smooth,
    showLabel = props.showLabel,
    dateFormat = props.dateFormat,
    rotateLabel = props.rotateLabel,
    scrollStart = props.scrollStart,
    yComplement = props.yComplement,
    disableMarks = props.disableMarks,
    fontLabelSize = props.fontLabelSize,
    toolboxTooltip = props.toolboxTooltip;
  var xData = data[0].values.map(function (item) {
    return item.label;
  });
  var formatLabel = function formatLabel(item) {
    var data = item.data;
    if (typeof yComplement === 'function' && (0, _typeof2["default"])(item) === 'object') {
      return yComplement(item.data);
    }
    if (typeof yComplement === 'function') {
      return yComplement;
    }
    return yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(Number(data)) + 'h' : (0, _auxiliarFunctions.takeLabelComplement)(Number(data), yComplement !== null && yComplement !== void 0 ? yComplement : '');
  };
  var formatTooltip = function formatTooltip(lines) {
    var takeComplement = function takeComplement(value) {
      return yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(Number(value)) + 'h' : (0, _auxiliarFunctions.takeLabelComplement)(Number(value), yComplement !== null && yComplement !== void 0 ? yComplement : '');
    };
    var linesTooltips = lines.map(function (line) {
      return line.seriesName + ': ' + takeComplement(Number(line.value)) + '<br>';
    });
    var tooltipTitle = xType === 'time' ? (0, _auxiliarFunctions.formatTime)(dateFormat === 'yyyy-MM' ? lines[0].name + '-02' : lines[0].name, (0, _auxiliarFunctions.getDateFormatType)(dateFormat !== null && dateFormat !== void 0 ? dateFormat : 'yyyy-MM')) : lines[0].name;
    return "".concat(tooltipTitle, " <br> ").concat(linesTooltips.join(' '));
  };
  var series = data.map(function (item) {
    return {
      type: 'line',
      smooth: smooth,
      name: item.name,
      showSymbol: !disableMarks,
      data: item.values.map(function (item) {
        return item.result;
      }),
      label: {
        distance: 1.1,
        show: showLabel,
        color: neutral[200],
        formatter: formatLabel,
        fontSize: yType === 'time' ? 10 : 11.5
      },
      lineStyle: {
        width: 1.5,
        type: item.name === 'ref' ? 'dashed' : undefined
      }
    };
  });
  var arrayInitialSize = scrollStart || (dateFormat === 'yyyy-MM' ? 12 : 30);
  var tooltipLabelFormat = dateFormat === 'yyyy-MM' ? 'MMM/yy' : 'dd/MM/yyyy';
  var scrollable = xData.length > arrayInitialSize ? [{
    type: 'inside',
    start: (0, _auxiliarFunctions.getInitialValues)(xData.length, dateFormat, scrollStart),
    end: 100,
    zoomLock: true,
    zoomOnMouseWheel: 'shift'
  }, {
    show: true,
    bottom: 10,
    type: 'slider',
    start: (0, _auxiliarFunctions.getInitialValues)(xData.length, dateFormat, scrollStart),
    end: 100,
    labelFormatter: function labelFormatter(_, item2) {
      return (0, _auxiliarFunctions.formatTime)(item2, tooltipLabelFormat);
    }
  }] : [];
  var toolbox = toolboxTooltip && _objectSpread(_objectSpread({}, _commonStyles.TOOLBOX_DEFAULT_PROPS), {}, {
    feature: {
      saveAsImage: toolboxTooltip.saveAsImage && (0, _auxiliarFunctions.getSaveAsImage)((_toolboxTooltip$saveA = toolboxTooltip.saveAsImage.title) !== null && _toolboxTooltip$saveA !== void 0 ? _toolboxTooltip$saveA : ''),
      dataView: toolboxTooltip.dataView && (0, _auxiliarFunctions.getDataView)((_toolboxTooltip$dataV = toolboxTooltip.dataView.title) !== null && _toolboxTooltip$dataV !== void 0 ? _toolboxTooltip$dataV : '')
    }
  });
  var getOption = function getOption() {
    return {
      color: colors,
      series: series,
      dataZoom: scrollable,
      grid: _objectSpread(_objectSpread({}, grid || {
        bottom: 75
      }), {}, {
        show: true
      }),
      title: {
        text: title,
        left: '6.2%',
        textStyle: _objectSpread({}, _commonStyles.TITLE_STYLE)
      },
      xAxis: {
        type: 'category',
        data: xData,
        boundaryGap: false,
        splitLine: {
          show: true,
          lineStyle: _objectSpread({}, _commonStyles.AXIS_SPLIT_LINE)
        },
        axisLabel: _objectSpread(_objectSpread({}, _commonStyles.COMMON_STYLE), {}, {
          rotate: rotateLabel || 0,
          fontSize: fontLabelSize || 11.5,
          formatter: function formatter(item) {
            return xType === 'time' ? (0, _auxiliarFunctions.formatTime)(dateFormat === 'yyyy-MM' ? item + '-02' : item, (0, _auxiliarFunctions.getDateFormatType)(dateFormat !== null && dateFormat !== void 0 ? dateFormat : 'yyyy-MM')) : item;
          }
        })
      },
      yAxis: {
        type: 'value',
        splitLine: {
          show: true,
          lineStyle: _objectSpread({}, _commonStyles.AXIS_SPLIT_LINE)
        },
        axisTick: {
          show: true
        },
        axisLine: {
          show: true,
          type: 'solid',
          lineStyle: {
            color: neutral[200]
          }
        },
        axisLabel: _objectSpread(_objectSpread({}, _commonStyles.COMMON_STYLE), {}, {
          fontSize: fontLabelSize || 11.5,
          margin: yType === 'time' ? 16 : 14,
          formatter: function formatter(item) {
            return yType === 'time' ? (0, _auxiliarFunctions.timeConvert)(item).toString() + 'h' : (0, _auxiliarFunctions.takeLabelComplement)(item, yComplement !== null && yComplement !== void 0 ? yComplement : '');
          }
        })
      },
      legend: {
        icon: _commonStyles.STRAIGHT_LINE_ICON,
        textStyle: _objectSpread({}, _commonStyles.COMMON_STYLE)
      },
      tooltip: _objectSpread({
        trigger: 'axis',
        formatter: formatTooltip
      }, _commonStyles.TOOLTIP_DEFAULT_PROPS),
      toolbox: _objectSpread(_objectSpread({}, toolbox), {}, {
        tooltip: _objectSpread(_objectSpread({}, _commonStyles.TOOLTIP_DEFAULT_PROPS), {}, {
          formatter: function formatter(param) {
            return "<div>".concat(param.title, "</div>");
          }
        })
      })
    };
  };
  return /*#__PURE__*/_react["default"].createElement(_core2["default"], {
    notMerge: true,
    lazyUpdate: true,
    echarts: echarts,
    option: getOption(),
    style: {
      width: '99.9%'
    },
    opts: {
      renderer: 'canvas',
      width: width !== null && width !== void 0 ? width : 'auto'
    }
  });
};
var _default = exports["default"] = LineChart;