"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.verifyStyleProps = exports.truncateLabel = exports.toDate = exports.toArgDateFns = exports.timeConvert = exports.thousandSeparator = exports.takeLabelComplement = exports.takeDonutChartComplement = exports.rotatedLabelSpecial = exports.rotatedLabel = exports.normalLabel = exports.mountMessage = exports.monuntTimeMessage = exports.getWidthOpts = exports.getSaveAsImageWithTitle = exports.getSaveAsImage = exports.getPercentage = exports.getInitialValues = exports.getDomain = exports.getDateFormatType = exports.getDataView = exports.generateAuxMessage = exports.fullText = exports.formatTooltipWithHours = exports.formatTooltip = exports.formatTime = exports.formatLabelWithImage = exports.fixedTruncateLabel = exports.fixedDomain = exports.dontShowLabel = exports.convertImageToBase64FromUrl = exports.changeSpaceForUnderline = exports.ICON_STYLE = exports.DOWNLOAD_ICON = exports.DATA_VIEW_ICON = void 0;
var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));
var _dateFns = require("date-fns");
var _ptBR = require("date-fns/locale/pt-BR");
var _theme = require("flipper-ui/theme");
var _theme$colors = _theme.theme.colors,
  neutral = _theme$colors.neutral,
  primary = _theme$colors.primary;
var DOWNLOAD_ICON = exports.DOWNLOAD_ICON = 'path://M19 12v7H5v-7H3v7c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2v-7h-2zm-6 ' + '.67l2.59-2.58L17 11.5l-5 5-5-5 1.41-1.41L11 12.67V3h2v9.67z';
var DATA_VIEW_ICON = exports.DATA_VIEW_ICON = 'path://M2 20h20v-4H2v4zm2-3h2v2H4v-2zM2 4v4h20V4H2zm4 ' + '3H4V5h2v2zm-4 7h20v-4H2v4zm2-3h2v2H4v-2z';
var ICON_STYLE = exports.ICON_STYLE = {
  color: primary.main,
  borderColor: primary.main,
  borderWidth: 0.1
};
var timeConvert = exports.timeConvert = function timeConvert(value) {
  var hrs = Math.floor(value);
  var min = Math.round((value - hrs) * 60);
  var hours = hrs.toString().length > 1 ? hrs : "0".concat(hrs);
  var minutes = min.toString().length > 1 ? min : "0".concat(min);
  return "".concat(hours, ":").concat(minutes);
};
var getPercentage = exports.getPercentage = function getPercentage(value, valueTotal) {
  return value !== 0 ? (value * (100 / valueTotal)).toFixed(2) : '0';
};

// These 3 next functions are used on the mountMessage function.
var formatValueAxis = function formatValueAxis(value, complement, typeChart) {
  var isMoney = typeof complement === 'function' ? complement(value) : value + complement;
  var getTime = complement === 'time' ? timeConvert(value) : isMoney;
  var formatValueIfComplementPercent = typeChart == 'pie' ? value.toFixed(2).replace('.', ',') : (value.toFixed(2) + '%').replace('.', ',');
  return complement === '%' || complement === 'percent' ? formatValueIfComplementPercent : getTime;
};
var takeComplement = function takeComplement(data, complement) {
  var value = (0, _typeof2["default"])(data) === 'object' ? data.value : data;
  return typeof complement === 'function' ? ': ' + complement(value) + '<br>' : ': ' + value + complement + '<br>';
};
var moneyWithPercentage = function moneyWithPercentage(moneyValue, moneyValueTotal, complement, sumDataValues) {
  var value = (0, _typeof2["default"])(moneyValue) === 'object' ? moneyValue.value : moneyValue;
  var percent = getPercentage(Number(value), moneyValueTotal);
  return sumDataValues ? complement(value) + ' (' + percent + '%) <br>' : complement(value) + '<br>';
};
var takeLabelComplement = exports.takeLabelComplement = function takeLabelComplement(item, yComplement, typeChart) {
  var getComplement = function getComplement(complement) {
    return complement ? formatValueAxis(item, complement, typeChart) : item;
  };
  return typeof yComplement === 'function' ? yComplement(item) : getComplement(yComplement);
};
var takeDonutChartComplement = exports.takeDonutChartComplement = function takeDonutChartComplement(item, complement) {
  return item === 0 && typeof complement === 'function' ? '' : "".concat(item, "  ").concat(complement ? "(".concat(complement, ")") : '');
};
var generateAuxMessage = exports.generateAuxMessage = function generateAuxMessage(label, result, complement) {
  var value = typeof complement === 'function' ? complement(result) : result;
  return "<span style=\"margin-left: 15.2px;\"></span>".concat(label, ": ").concat(value, "<br>");
};
var monuntTimeMessage = exports.monuntTimeMessage = function monuntTimeMessage(item, stackedValues) {
  var time = timeConvert(Number(item.value));
  var percent = item.value !== 0 ? getPercentage(Number(item.value), stackedValues) : '0';
  return item.seriesName + ': ' + time + ' (' + percent + '%) <br>';
};

// Specific function only used in the stacked bar chart tooltip
var mountMessage = exports.mountMessage = function mountMessage(value, complement, axisType, stackedValues, sumDataValues) {
  var _value$data, _value$data2;
  var seriesLabel = (value.marker ? value.marker : '') + (value.seriesName ? value.seriesName : '');
  var moneyValue = typeof complement === 'function' ? moneyWithPercentage((_value$data = value.data) !== null && _value$data !== void 0 ? _value$data : '', stackedValues, complement, sumDataValues) : '';
  var isPercentage = axisType === 'percent' || complement === '%' ? seriesLabel + ': ' + (formatValueAxis(Number(value.data), '%') + '<br>') : seriesLabel + takeComplement((_value$data2 = value.data) !== null && _value$data2 !== void 0 ? _value$data2 : '', complement);
  return typeof complement === 'function' && value.seriesType !== 'line' ? seriesLabel + ': ' + moneyValue : isPercentage;
};
var getDateFormatType = exports.getDateFormatType = function getDateFormatType(dateFormat, baseFormat) {
  if (dateFormat === 'yyyy-MM') {
    return baseFormat ? baseFormat : 'MMM/yy';
  }
  return dateFormat;
};
var toArgDateFns = exports.toArgDateFns = function toArgDateFns(date) {
  return typeof date === 'string' ? (0, _dateFns.parseISO)(date) : date;
};
var formatTime = exports.formatTime = function formatTime(text) {
  var dateFormat = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'dd MMM';
  var hasTime = text.includes(':');
  var date = hasTime ? new Date(text) : new Date(text + 'T00:00:00');
  return (0, _dateFns.format)(toArgDateFns(date), dateFormat, {
    locale: _ptBR.ptBR
  });
};
var toDate = exports.toDate = function toDate(text, format) {
  return (0, _dateFns.parse)(text, format ? format : 'yyyy-MM-dd', new Date());
};
var formatTooltip = exports.formatTooltip = function formatTooltip(text) {
  var dateFormat = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'dd MMM';
  var hasTime = text.includes(':');
  var date = hasTime ? new Date(text) : new Date(text + 'T00:00:00');
  return (0, _dateFns.format)(toArgDateFns(date), getDateFormatType(dateFormat), {
    locale: _ptBR.ptBR
  });
};
var formatTooltipWithHours = exports.formatTooltipWithHours = function formatTooltipWithHours(text) {
  return (0, _dateFns.format)(toArgDateFns(new Date(text)), 'dd/MM/yyyy HH:mm', {
    locale: _ptBR.ptBR
  });
};
var truncateLabel = exports.truncateLabel = function truncateLabel(text, labelWordSize) {
  var numberOfLetters = labelWordSize ? labelWordSize : 12;
  var lettersToShow = labelWordSize ? 3 : 4;
  return text.length > numberOfLetters ? text.slice(0, numberOfLetters - lettersToShow) + '...' : text;
};
var fixedTruncateLabel = exports.fixedTruncateLabel = function fixedTruncateLabel(text, size) {
  return text.length > size ? text.slice(0, size - 3) + '...' : text;
};

// This is a xgh that needs improvments, it's used to take the domain
// of the line and area charts, there is the range of the y axis that
// is printed on component.
var getDomain = exports.getDomain = function getDomain(item) {
  switch (true) {
    case item.max >= 2500:
      return item.max + item.max * 20 / 100;
    case item.max >= 2000:
      return item.max + (400 - item.max % 400);
    case item.max >= 1500:
      return item.max + (300 - item.max % 300);
    case item.max >= 1000:
      return item.max + (200 - item.max % 200);
    case item.max >= 400:
      return item.max + (100 - item.max % 100);
    case item.max >= 95:
      return item.max + (60 - item.max % 60);
    case item.max >= 60:
      return item.max + (50 - item.max % 50);
    case item.max >= 50:
      return item.max + (40 - item.max % 40);
    case item.max >= 40:
      return item.max + (30 - item.max % 30);
    case item.max >= 30:
      return item.max + (20 - item.max % 20);
    case item.max >= 20:
      return item.max + (10 - item.max % 10);
    case item.max >= 2:
      return item.max + (5 - item.max % 5);
    default:
      return item.max + (3 - item.max % 3);
  }
};
var fixedDomain = exports.fixedDomain = function fixedDomain(item) {
  return item.max >= 90 ? 100 : getDomain(item);
};
var getSaveAsImage = exports.getSaveAsImage = function getSaveAsImage(title, name) {
  return {
    title: title,
    name: name,
    type: 'jpeg',
    show: true,
    icon: DOWNLOAD_ICON,
    iconStyle: ICON_STYLE,
    excludeComponents: ['toolbox', 'dataZoom']
  };
};
var getDataView = exports.getDataView = function getDataView(title) {
  return {
    title: title,
    show: true,
    icon: DATA_VIEW_ICON,
    iconStyle: ICON_STYLE,
    buttonColor: primary.main,
    // TODO: pass this labels as a props from the component use.
    lang: [title, 'Voltar', 'Atualizar']
  };
};

// This function get the initial values, the range of the initial
// scroll, that are used at scrollable charts with dates.
// 30 values for monthly charts, 12 for yearly charts.
var getInitialValues = exports.getInitialValues = function getInitialValues(arrayLength, dateFormat, scrollStart) {
  if (scrollStart) {
    return arrayLength > scrollStart ? 100 - scrollStart * 100 / arrayLength : 0;
  }
  var monthly = arrayLength > 30 ? 100 - 3000 / arrayLength : 0;
  var yearly = arrayLength > 12 ? 100 - 1200 / arrayLength : 0;
  return dateFormat !== 'yyyy-MM' ? monthly : yearly;
};

// This function take a number and put on this the thousand separator ".", e.g.:
// 1000 => 1.000
// 1000000 => 1.000.000
var thousandSeparator = exports.thousandSeparator = function thousandSeparator(values) {
  return values.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
};

// This function is used to print the title on chart image download even
// the chart's title is not rendered on the component.
var getSaveAsImageWithTitle = exports.getSaveAsImageWithTitle = function getSaveAsImageWithTitle(title, setTitle, name) {
  return {
    title: title,
    name: name,
    show: true,
    icon: DOWNLOAD_ICON,
    iconStyle: ICON_STYLE,
    onclick: function onclick(item, chartInfo) {
      var title = item.option.title.length > 0 ? item.option.title[0].text : 'image';
      setTitle(true);
      var url = chartInfo.getConnectedDataURL({
        type: 'jpg',
        backgroundColor: neutral[50],
        connectedBackgroundColor: neutral[50],
        excludeComponents: ['toolbox', 'dataZoom']
      });
      var a = document.createElement('a');
      a.download = title + '.jpeg';
      a.target = '_blank';
      a.href = url;
      var event = new MouseEvent('click', {
        view: document.defaultView,
        bubbles: true,
        cancelable: false
      });
      a.dispatchEvent(event);
      setTitle(false);
    }
  };
};
var getWidthOpts = exports.getWidthOpts = function getWidthOpts(width) {
  return {
    width: width
  };
};
var convertImageToBase64FromUrl = exports.convertImageToBase64FromUrl = function convertImageToBase64FromUrl(imgUrl) {
  return new Promise(function (resolve) {
    var img = new Image();
    img.src = imgUrl;
    img.setAttribute('crossOrigin', 'anonymous');
    img.onload = function () {
      var canvas = document.createElement('canvas');
      var ctx = canvas.getContext('2d');
      canvas.width = 40;
      canvas.height = 40;
      if (ctx) {
        canvas.width = 40;
        canvas.height = 40;
        ctx.save();
        ctx.beginPath();
        ctx.arc(40 / 2, 40 / 2, 40 / 2, 0, Math.PI * 2);
        ctx.clip();
        ctx.drawImage(img, 0, 0, 40, 40);
        ctx.restore();
        var dataUrl = ctx.canvas.toDataURL('image/png');
        resolve(dataUrl);
      }
    };
  });
};
var changeSpaceForUnderline = exports.changeSpaceForUnderline = function changeSpaceForUnderline(value) {
  return value.replace(' ', '_');
};
var formatLabelWithImage = exports.formatLabelWithImage = function formatLabelWithImage(text) {
  var textFormatted = '{value|' + text + '} {' + changeSpaceForUnderline(text) + '| }';
  return textFormatted;
};
var verifyStyleProps = exports.verifyStyleProps = function verifyStyleProps(data) {
  return data.style ? {
    value: data.result,
    itemStyle: data.style
  } : data.result;
};
var dontShowLabel = exports.dontShowLabel = {
  grid: {
    bottom: 75
  },
  xAxis: {
    axisLabel: {
      interval: 1,
      rotate: 0
    }
  }
};
var normalLabel = exports.normalLabel = {
  grid: {
    bottom: 75
  },
  xAxis: {
    axisLabel: {
      show: true,
      rotate: 0,
      interval: 0,
      formatter: function formatter(item) {
        return fixedTruncateLabel(item, 9);
      }
    }
  }
};
var fullText = exports.fullText = {
  grid: {
    bottom: 75
  },
  xAxis: {
    axisLabel: {
      show: true,
      rotate: 0,
      interval: 0,
      formatter: function formatter(item) {
        return fixedTruncateLabel(item, 16);
      }
    }
  }
};
var rotatedLabel = exports.rotatedLabel = {
  grid: {
    bottom: 98
  },
  xAxis: {
    axisLabel: {
      show: true,
      rotate: 315,
      interval: 0,
      formatter: function formatter(item) {
        return fixedTruncateLabel(item, 9);
      }
    }
  }
};
var rotatedLabelSpecial = exports.rotatedLabelSpecial = function rotatedLabelSpecial(rotate) {
  return {
    grid: {
      bottom: 98
    },
    xAxis: {
      axisLabel: {
        show: true,
        interval: 0,
        rotate: rotate,
        textStyle: {
          fontSize: 11
        },
        formatter: function formatter(item) {
          return fixedTruncateLabel(item, 9);
        }
      }
    }
  };
};